==> BSgenome.Celegans.UCSC.ce6_1.3.17.tar.gz: BSgenome.Celegans.UCSC.ce6/man/package.Rd <==
\name{Celegans}
\docType{package}

\alias{BSgenome.Celegans.UCSC.ce6-package}
\alias{BSgenome.Celegans.UCSC.ce6}
\alias{Celegans}


\title{Caenorhabditis elegans (Worm) full genome (UCSC version ce6)}

\description{
  Caenorhabditis elegans (Worm) full genome as provided by UCSC (ce6, May 2008) and stored in Biostrings objects.
}

\details{
  
}

\note{
  This BSgenome data package was made from the following source data files:
  \preformatted{
chromFa.tar.gz
upstream1000.fa.gz
upstream2000.fa.gz
upstream5000.fa.gz
from ftp://hgdownload.cse.ucsc.edu/goldenPath/ce6/bigZips/

  }
  See \code{?\link[BSgenome]{BSgenomeForge}} and the BSgenomeForge
  vignette (\code{vignette("BSgenomeForge")}) in the BSgenome software
  package for how to make a BSgenome data package.
}

\author{H. Pages}

\seealso{
  \link[BSgenome]{BSgenome-class},
  \link[Biostrings]{DNAString-class},
  \code{\link[BSgenome]{available.genomes}},
  \link[BSgenome]{BSgenomeForge}
}

\examples{
Celegans
seqlengths(Celegans)
Celegans$chrI  # same as Celegans[["chrI"]]

if ("AGAPS" \%in\% masknames(Celegans)) {

  ## Check that the assembly gaps contain only Ns:
  checkOnlyNsInGaps <- function(seq)
  {
    ## Replace all masks by the inverted AGAPS mask
    masks(seq) <- gaps(masks(seq)["AGAPS"])
    unique_letters <- uniqueLetters(seq)
    if (any(unique_letters != "N"))
        stop("assembly gaps contain more than just Ns")
  }

  ## A message will be printed each time a sequence is removed
  ## from the cache:
  options(verbose=TRUE)

  for (seqname in seqnames(Celegans)) {
    cat("Checking sequence", seqname, "... ")
    seq <- Celegans[[seqname]]
    checkOnlyNsInGaps(seq)
    cat("OK\n")
  }
}

## See the GenomeSearching vignette in the BSgenome software
## package for some examples of genome-wide motif searching using
## Biostrings and the BSgenome data packages:
if (interactive())
    vignette("GenomeSearching", package="BSgenome")
}

\keyword{package}
\keyword{data}

==> BSgenome.Celegans.UCSC.ce6_1.3.19.tar.gz: BSgenome.Celegans.UCSC.ce6/man/package.Rd <==
\name{BSgenome.Celegans.UCSC.ce6}
\docType{package}

\alias{BSgenome.Celegans.UCSC.ce6-package}
\alias{BSgenome.Celegans.UCSC.ce6}
\alias{Celegans}

\title{Caenorhabditis elegans (Worm) full genome (UCSC version ce6)}

\description{
  Caenorhabditis elegans (Worm) full genome as provided by UCSC (ce6, May 2008) and stored in Biostrings objects.
}

\details{
  
}

\note{
  This BSgenome data package was made from the following source data files:
  \preformatted{
chromFa.tar.gz
upstream1000.fa.gz
upstream2000.fa.gz
upstream5000.fa.gz
from ftp://hgdownload.cse.ucsc.edu/goldenPath/ce6/bigZips/

  }
  See \code{?\link[BSgenome]{BSgenomeForge}} and the BSgenomeForge
  vignette (\code{vignette("BSgenomeForge")}) in the BSgenome software
  package for how to make a BSgenome data package.
}

\author{The Bioconductor Dev Team}

\seealso{
  \link[BSgenome]{BSgenome-class},
  \link[Biostrings]{DNAString-class},
  \code{\link[BSgenome]{available.genomes}},
  \link[BSgenome]{BSgenomeForge}
}

\examples{
BSgenome.Celegans.UCSC.ce6
genome <- BSgenome.Celegans.UCSC.ce6
seqlengths(genome)
genome$chrI  # same as genome[["chrI"]]

if ("AGAPS" \%in\% masknames(genome)) {

  ## Check that the assembly gaps contain only Ns:
  checkOnlyNsInGaps <- function(seq)
  {
    ## Replace all masks by the inverted AGAPS mask
    masks(seq) <- gaps(masks(seq)["AGAPS"])
    unique_letters <- uniqueLetters(seq)
    if (any(unique_letters != "N"))
        stop("assembly gaps contain more than just Ns")
  }

  ## A message will be printed each time a sequence is removed
  ## from the cache:
  options(verbose=TRUE)

  for (seqname in seqnames(genome)) {
    cat("Checking sequence", seqname, "... ")
    seq <- genome[[seqname]]
    checkOnlyNsInGaps(seq)
    cat("OK\n")
  }
}

## See the GenomeSearching vignette in the BSgenome software
## package for some examples of genome-wide motif searching using
## Biostrings and the BSgenome data packages:
if (interactive())
    vignette("GenomeSearching", package="BSgenome")
}

\keyword{package}
\keyword{data}
